
.. _views:

.. currentmodule:: jgrapht.views

Views 
*****

Graph views are wrappers around a graph which adjust its functionality. These 
views are live, meaning that changes in the original graph are reflected in the 
view and vice-versa.

.. automodule:: jgrapht.views
   :members:

